.. highlight:: shell

============
Installation
============


Stable release
--------------

To install badgr-lite, run this command in your terminal:

.. code-block:: console

    $ pip install badgr-lite

This is the easiest method to install badgr-lite, as it will always install the
most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


The newly recommended way to install is to use pipenv. Run this command in your terminal:

.. code-block:: console

    $ pipenv install badgr-lite

This is the python.org preferred method to install badgr-lite, as it will
better manage dependency and security.

If you don't have `pipenv`_ installed, this `PyCon Video`_ can guide
will help.

.. _pipenv: https://github.com/pypa/pipenv
.. _PyCon Video: https://www.youtube.com/watch?v=GBQAKldqgZs


From sources
------------

The sources for badgr-lite can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/glenjarvis/badgr_lite

Or download the `tarball`_:

.. code-block:: console

    $ curl -OJL https://github.com/glenjarvis/badgr_lite/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/glenjarvis/badgr_lite
.. _tarball: https://github.com/glenjarvis/badgr_lite/tarball/master
